@@ -4,7 +4,7 @@ import bpy
 import pandas as pd
 
 class init_anim:
-    def __init__(self, t, speed_up):
+    def __init__(self, t, speed_up, scale):
         self.frame_rate = bpy.context.scene.render.fps
         
         self.t = t
@@ -14,12 +14,14 @@ class init_anim:
         self.frames = np.linspace(1, int(t[-1]*self.frame_rate/speed_up), len(t)).astype(int)
         
         self.frame_duration = self.frames[-1]
+
+        self.scale = scale
         
         bpy.context.scene.frame_start = 1
         bpy.context.scene.frame_end = self.frame_duration+1
 
 class ref_frame:
-    def __init__(self, name, parent):
+    def __init__(self, name, parent, init_anim):
         self.name = name
         self.parent = parent
         
@@ -30,6 +32,10 @@ class ref_frame:
         self.ob.parent = parent
         self.ob.empty_display_type = 'ARROWS'
         self.ob.rotation_mode = 'QUATERNION'
+
+        self.frames = init_anim.frames
+        self.scale = init_anim.scale
+
         
     def static_6DOF(self, quat, x, y, z):
         if not(quat is None):
@@ -37,11 +43,13 @@ class ref_frame:
             self.ob.rotation_quaternion[2] = quat[1]
             self.ob.rotation_quaternion[3] = quat[2]
             self.ob.rotation_quaternion[0] = quat[3]
+
         
         if not((x is None or y is None) or z is None):
             self.ob.location = (x, y, z)
         
-    def dynamic_6DOF(self, quat, x_list, y_list, z_list, frames):
+    def dynamic_6DOF(self, quat, x_list, y_list, z_list):
+        frames = self.frames
         if not(quat is None):
             for i in range(len(frames)):
                 cur_frame = frames[i]
@@ -58,9 +66,9 @@ class ref_frame:
         if not(x_list is None):
             for i in range(len(frames)):
                 cur_frame = frames[i]
-                cur_x = x_list[i]
-                cur_y = y_list[i]
-                cur_z = z_list[i]
+                cur_x = x_list[i]/self.scale
+                cur_y = y_list[i]/self.scale
+                cur_z = z_list[i]/self.scale
             
                 self.ob.location = (cur_x, cur_y, cur_z)
             
@@ -68,7 +76,7 @@ class ref_frame:
         
 
 class dyn_obj:
-    def __init__(self, obj, pa, euler_type, parent):
+    def __init__(self, obj, pa, euler_type, parent, init_anim):
         
         self.euler_pa = pa
         
@@ -82,9 +90,14 @@ class dyn_obj:
         self.body = ref_frame(obj.name+'_body', self.pa_axes.ob)
         
         obj.parent = self.body.ob
+        obj.scale = (scale, scale, scale)
+
         self.body.static_6DOF(-self.quat, None, None, None)
 
         self.name = obj.name
+
+        self.frames = init_anim.frames
+        self.scale = init_anim.scale
         
     def apply_animation(self, x_list, y_list, z_list, quat_list, frames):
         
@@ -96,9 +109,9 @@ class dyn_obj:
         
         int_size = len(int_x)
         int_coords = np.zeros((int_size, 3))
-        int_coords[:, 0] = int_x
-        int_coords[:, 1] = int_y
-        int_coords[:, 2] = int_z
+        int_coords[:, 0] = int_x/self.scale
+        int_coords[:, 1] = int_y/self.scale
+        int_coords[:, 2] = int_z/self.scale
 
         int_curve = bpy.data.curves.new(name, type='CURVE')
         int_curve.dimensions = '3D'
